==> lein-template-0.1.3.jar: leiningen/new/ring_micro/project.clj <==
(defproject {{name}} "0.1.0"
  :description "A template for building microservices with Ring on Containers"
  :url "https://github.com/FIXME/{{name}}"
  :license {:name "Eclipse Public License"
            :url "http://www.eclipse.org/legal/epl-v10.html"}
  :scm {:name "git"
        :url "https://github.com/FIXME/{{name}}"}
  :min-lein-version "2.5.0"
  :jvm-opts ["-Xms768m" "-Xmx768m"]
  :global-vars {*warn-on-reflection* false *assert* false}
  :dependencies [[org.clojure/clojure "1.6.0"]
                 [org.clojure/core.async "0.1.346.0-17112a-alpha"]
                 [org.clojure/tools.logging "0.3.1"]
                 [ring/ring-core "1.3.2"]
                 [ring/ring-defaults "0.1.5"]
                 [ring/ring-headers "0.1.3"]
                 [ring/ring-json "0.3.1"]
                 [fogus/ring-edn "0.2.0"]
                 [ring-cors "0.1.7"]
                 [compojure "1.3.4"]
                 [http-kit "2.1.18"]
                 [prone "0.8.1"]
                 [environ "1.0.0"]]
  :profiles {:dev {:dependencies [[ring/ring-mock "0.2.0"]
                                  [ring/ring-devel "1.3.2"]]
                   :env {:is-dev true}}
             :uberjar {:env {:production true}
                       :omit-source true
                       :aot :all}}
  :plugins [[lein-ring "0.9.3"]
            [lein-environ "1.0.0"]
            [lein-kibit "0.0.8"]
            [lein-pprint "1.1.1"]
            [lein-pdo "0.1.1"]
            [lein-cljfmt "0.1.10"]
            [jonase/eastwood "0.2.1"]]
  :aliases {"dev" ["ring" "server"]
            "analyze" ["pdo" "kibit," "eastwood"]
            "format" ["cljfmt" "check"]
            "prod" ["pdo" "clean," "uberjar"]}
  :ring {:handler {{name}}.server/app}
  :main ^:skip-aot {{name}}.server
  :uberjar-name "{{name}}.jar")

==> lein-template-0.1.4.jar: leiningen/new/ring_micro/project.clj <==
(defproject {{name}} "0.1.0"
  :description "A template for building microservices with Ring, batteries included"
  :url "https://github.com/FIXME/{{name}}"
  :license {:name "Eclipse Public License"
            :url "http://www.eclipse.org/legal/epl-v10.html"}
  :scm {:name "git"
        :url "https://github.com/FIXME/{{name}}"}
  :min-lein-version "2.5.0"
  :jvm-opts ["-Xms512m" "-server"]
  :global-vars {*warn-on-reflection* false *assert* false}

  :dependencies [[org.clojure/clojure "1.7.0"]
                 [org.clojure/core.async "0.1.346.0-17112a-alpha"]
                 [org.clojure/tools.nrepl "0.2.10"]
                 [org.clojure/tools.logging "0.3.1"]
                 [ring/ring-core "1.4.0-RC2"]
                 [ring/ring-defaults "0.1.5"]
                 [ring/ring-headers "0.1.3"]
                 [ring/ring-json "0.3.1"]
                 [fogus/ring-edn "0.2.0"]
                 [ring-cors "0.1.7"]
                 [compojure "1.3.4"]
                 [http-kit "2.1.18"]
                 [prone "0.8.1"]
                 [environ "1.0.0"]]

  :profiles {:dev {:dependencies [[ring/ring-mock "0.2.0"]
                                  [ring/ring-devel "1.3.2"]]
                   :env {:is-dev true}}
             :uberjar {:env {:production true}
                       :omit-source true
                       :aot :all}}
  :plugins [[cider/cider-nrepl "0.8.2"]
            [lein-ring "0.9.3"]
            [lein-environ "1.0.0"]
            [lein-kibit "0.0.8"]
            [lein-pprint "1.1.1"]
            [lein-pdo "0.1.1"]
            [lein-cljfmt "0.1.10"]
            [jonase/eastwood "0.2.1"]]
  :aliases {"dev" ["ring" "server"]
            "analyze" ["pdo" "kibit," "eastwood"]
            "format" ["cljfmt" "check"]
            "prod" ["pdo" "clean," "uberjar"]}
  :ring {:handler {{name}}.server/app}
  :main ^:skip-aot {{name}}.server)
